function [uZ eZ] = eig_kron(uX_prime,eX,uY_prime,eY)

% Computes the inverse of the Kronecker product of two matrices, given the
% eigen-decomposition of those matrices.
%
% [uZ eZ] = inv_kron(uX_prime,eX,uY_prime,eY);
%
% Input : 
% uX_prime : orthogonal matrix. size n*n
% eX : vector. size n*1
% uY_prime : orthogonal matrix. size p*p
% eY : vector. size p*1
%
% Output :
% uZ : orthogonal matrix. size np*np
% eZ : vector. size np*1
% 
% If 
% X = uX_prime'*diag(eX)*uX_prime (symetrical, size n)
% Y = uY_prime'*diag(eY)*uY_prime (symetrical, size p)
% then Z = kron(X,Y)^(-1) suche_that Z = uZ*diag(eZ)*uZ'

n = size(uX_prime,1);
p = size(uY_prime,1);
eZ = max(real(kron(eX,eY)),0);
uZ = zeros(n*p,n*p);

for i = 1:n
    for j = 1:p
        uZ(:,p*(i-1)+j) = kron(uX_prime(:,i),uY_prime(:,j));
    end
end
uZ = uZ';
end


